=========
metaindex
=========
---------------------------
document search by metadata
---------------------------

.. include:: source/synopsis.rst

Description
===========

.. include:: source/description.rst

.. include:: source/cmdoptions.rst


Files
=====

metaindex is controlled through a configuration file and caches metadata in a
cache file.


Cache file
----------

The cache file is usually located in ``~/.cache/metaindex/index.db``, but that
location is configurable.

.. include:: source/configuration.rst


.. include:: source/searchsyntax.rst


.. include:: source/extrametadata.rst


.. include:: source/indexers.rst


.. include:: source/addons.rst


Usage Examples
==============


Commandline Usage
-----------------

.. include:: source/cmdusage.rst

Bugs
====

Surely. Please report anything that you find at
https://github.com/vonshednob/metaindex or via email to the authors.

